#
# spec file for package perl-Devel-Confess
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Devel-Confess
Version:        0.008000
Release:        6.1
%define cpan_name Devel-Confess
Summary:        Include stack traces on all warnings and errors
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Devel-Confess/
Source0:        http://www.cpan.org/authors/id/H/HA/HAARG/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
This module is meant as a debugging aid. It can be used to make a script
complain loudly with stack backtraces when warn()ing or die()ing. Unlike
other similar modules (e.g. the Carp::Always manpage), it includes stack
traces even when exception objects are thrown.

The stack traces are generated using the Carp manpage, and will look work
for all types of errors. the Carp manpage's 'carp' and 'confess' functions
will also be made to include stack traces.

  # it works for explicit die's and warn's
  $ perl -d:Confess -e 'sub f { die "arghh" }; sub g { f }; g'
  arghh at -e line 1.
          main::f() called at -e line 1
          main::g() called at -e line 1

  # it works for interpreter-thrown failures
  $ perl -d:Confess -w -e 'sub f { $a = shift; @a = @$a };' \
                                        -e 'sub g { f(undef) }; g'
  Use of uninitialized value $a in array dereference at -e line 1.
          main::f(undef) called at -e line 2
          main::g() called at -e line 2

Internally, this is implemented with '$SIG{__WARN__}' and '$SIG{__DIE__}'
hooks.

Stack traces are also included if raw non-object references are thrown.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README

%changelog
* Sat Jun 27 2015 coolo@suse.com
- updated to 0.008000
  see /usr/share/doc/packages/perl-Devel-Confess/Changes
  0.008000 - 2015-06-26
  - if dump option is used, bare references and objects without stringify
    overloads will be dumpered when being output to the screen
  - stack trace properly attached to bare references are rethrown and will be
    output to the screen
  - avoid Test::More in threads test to limit code run as much as possible
  - other test cleanups
  - fix DEBUGGING detection in newer perls
  - protect tests against DEVEL_CONFESS_OPTIONS set in environment
* Thu Apr 16 2015 coolo@suse.com
- updated to 0.007012
  see /usr/share/doc/packages/perl-Devel-Confess/Changes
  0.007012 - 2015-03-30
  - avoid re-throwing errors during END on debugging perls
* Sat Feb  7 2015 coolo@suse.com
- updated to 0.007011
  - avoid triggering overloads when CLONEing
  0.007010 - 2015-01-29
  - fix incorrect version check that prevented using better names option
  - fix removing hooks when unimport called
  - fix stringifying refs in stack trace inside a Safe compartment on old perl
  - avoid updating stored refaddrs when they haven't changed
  - less noise when checking for broken threads
  - prevent leaking namespaces even in broken threads
  - fix version check for broken threads
  0.007009 - 2015-01-23
  - prevent segfaults on perl 5.10.0 and 5.8.9 with threads
  - fix leaking exception objects if another is thrown or a thread created
  0.007008 - 2015-01-20
  - don't attempt threading tests if threading is broken
  0.007007 - 2015-01-19
  - fatal warnings in destructors can cause segfaults, so disable them
  - protect against losing information during global destruction and then
    triggering our own errors
  - improve stack trace formatting when generated during global destruction
  0.007006 - 2015-01-08
  - don't delete packages that exceptions are currently blessed as
  - protect tests against other loaded modules effecting hooks
  - add test for warning passing fix from 0.007005
  0.007005 - 2014-12-16
  - fix how we pass options on to other warn/die handlers (RT#100951)
  - minor pod cleanups
  - improve diagnostics for bad options in DEVEL_CONFESS_OPTIONS
  0.007004 - 2014-09-22
  - make sure unwanted debugging flags are disabled as early as possible,
* Tue Sep 16 2014 coolo@suse.com
- initial package 0.007003
  * created by cpanspec 1.78.08
